@@ -11,9 +11,7 @@ class Schema(object):
     def gen_field_name(field_pos:int):
         return Schema.default_name.format(field_pos)
 
-    def __init__(self
-        , name:str):
-        self._name = name
+    def __init__(self):
         self._schema = []
         self._pks = []
         self._alias = {}
@@ -28,7 +26,6 @@ class Schema(object):
         caracteristics of a field.
         """
 
-
         def __init__(self
             , name:str
             , ftype=str
@@ -107,9 +104,9 @@ class Schema(object):
             # valida a variavel
             if type(name) is not str:
                 raise Exception("The field name must be a string.")
-            if not re.fullmatch(re.compile(r"[A-Za-z0-9]+"), name):
-                raise Exception("Fields must have alphanumeric names, containing only letters and numbers.")
-            if re.fullmatch(re.compile(r"[0-9]"), name):
+            if not re.fullmatch(re.compile(r"[A-Za-z0-9\_]+"), name):
+                raise Exception("Fields must have alphanumeric names, containing only letters, numbers and the character '_'.")
+            if re.fullmatch(re.compile(r"[0-9\_]"), name):
                 raise Exception("Field names must always start with letters.")
             self._f['name'] = name
             return self
@@ -145,13 +142,12 @@ class Schema(object):
         return len(self._schema)
 
     def to_sql(self
+        , tablename:str
         , cmd_prefix=''
         , cmd_sufix=''
         , max_limit=400
         , min_limit=6
-        , exclude_zero_lenght=True
-        # remove o tablename pq eh obrigatorio ter um nome
-        , tablename:str=None)->str:
+        , exclude_zero_lenght=True)->str:
         return self.sql_create_table(tablename=tablename
             , cmd_prefix=cmd_prefix
             , cmd_sufix=cmd_sufix
@@ -173,13 +169,12 @@ class Schema(object):
         return field.get_name()
 
     def sql_create_table(self
+        , tablename:str
         , cmd_prefix=''
         , cmd_sufix=''
         , max_limit=400
         , min_limit=6
-        , exclude_zero_lenght=True
-        # remove o tablename pq eh obrigatorio ter um nome
-        , tablename:str=None)->str:
+        , exclude_zero_lenght=True)->str:
         """
         Cria comando SQL para create table.
         """
@@ -234,23 +229,19 @@ class Schema(object):
             field_list.append(sql_field_schema(field=f
                 , max_limit=max_limit
                 , min_limit=min_limit) + "\n")
-        return cmd_prefix + "CREATE TABLE {} (\n\t  ".format(self._name) + "\t, ".join(field_list) + ")" + cmd_sufix
+        return cmd_prefix + "CREATE TABLE {} (\n\t  ".format(tablename) + "\t, ".join(field_list) + ")" + cmd_sufix
 
-    def copy(self, newname=None, deep:bool=False)->Schema:
+    def copy(self, deep:bool=False)->Schema:
         """
         Faz uma copia do objeto de Schema.
         Eh usado quando se faz copias
         de Datasets.
         """
         cp = copy.deepcopy(self) if deep else copy.copy(self)
-        if not newname:
-            newname=self._name + '_cp'
-        cp._name = newname
         return cp
 
     def __deepcopy__(self, mode):
-        cp = Schema(self._name)
-        # cp._name = self._name
+        cp = Schema()
         for f in self._schema:
             fcp = copy.deepcopy(f)
             fcp._schema = cp
@@ -265,7 +256,6 @@ class Schema(object):
 
     def __copy__(self):
         cp = object.__new__(type(self))
-        cp._name = self._name
         cp._schema = copy.copy(self._schema)
         cp._pks = copy.copy(self._pks)
         cp._alias = copy.copy(self._alias)
@@ -356,7 +346,7 @@ class Schema(object):
         ocupa na lista de campos do schema.
         """
         if type(name) is int:
-            if name>=len(self._schema):
+            if name>len(self._schema):
                 # print(str(self))
                 raise Exception("'%s' eh uma posicao alem da quantidade %s de campos no esquema do dataset." % (name, len(self._schema)))
             return name
@@ -364,8 +354,6 @@ class Schema(object):
             allpos = self.get_all_field_pos()
             pos = allpos.get(name, None)
             return pos
-            # if pos<1: raise Exception("'%s' eh um campo que nao existe do esquema do dataset." % name)
-            return pos+1
         else:
             raise Exception("Tipo nao identificado.")
 
@@ -394,13 +382,15 @@ class Schema(object):
         return self
 
     def get_field(self, aliasname:str):
+        """
+        """
         flist = self.get_all_field_pos()
         fpos = flist.get(aliasname, 0)
-        if fpos:
-            return self._schema[fpos-1]
-
+        return self._schema[fpos-1] if fpos else None
 
     def get_all_field_pos(self)->dict:
+        """
+        """
         allpos = {}
         for i, f in enumerate(self._schema):
             allpos[f.get_name()]=i+1
@@ -423,8 +413,6 @@ class Schema(object):
             self._schema[col_ref:col_ref] = [field]
         return self
 
-
-
     def pk(self
         , name:str=None
         , ftype=int
@@ -526,8 +514,7 @@ class Schema(object):
         Return a third schema who defines the
         relation.
         """
-        new_schema_name = "{}_{}".format(self._name, schema._name)
-        bridge = Schema(name=new_schema_name)
+        bridge = Schema()
         self.has(bridge, identified, source_fields, source_alias)
         schema.has(bridge, identified, target_fields, target_alias)
         return bridge
